/********************************************************************************
 * Copyright (C) 2018 TypeFox and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
import { DebugConfiguration } from '@theia/debug/lib/common/debug-configuration';
import { MessageService, CommandService } from '@theia/core/lib/common';
import { QuickPickService, QuickPickItem } from '@theia/core/lib/common/quick-pick-service';
import { AbstractVSCodeDebugAdapterContribution } from '@theia/debug/lib/node/vscode/vscode-debug-adapter-contribution';
export declare namespace VSCodePythonDebugCommands {
    const VALIDATE_LAUNCH_CONFIG = "vscode.python.validateLaunchConfig";
    const START_DEBUG_SESSION = "vscode.debug.startDebugging";
}
export interface MainClassOption {
    readonly mainClass: string;
    readonly projectName?: string;
    readonly filePath?: string;
}
interface ValidationResult {
    readonly isValid: boolean;
    readonly message?: string;
}
interface LaunchValidationResponse {
    readonly mainClass: ValidationResult;
    readonly projectName: ValidationResult;
    readonly proposals?: MainClassOption[];
}
export declare class PythonDebugExtensionContribution extends AbstractVSCodeDebugAdapterContribution {
    constructor();
}
export declare class PythonDebugAdapterContribution extends PythonDebugExtensionContribution {
    protected readonly commands: CommandService;
    protected readonly messages: MessageService;
    protected readonly quickPickService: QuickPickService;
    provideDebugConfigurations(workspaceFolderUri?: string): Promise<DebugConfiguration[]>;
    protected constructLaunchConfigName(mainClass: string, projectName: string | undefined, cache: {
        [name: string]: number;
    }): string;
    resolveDebugConfiguration(config: DebugConfiguration, workspaceFolderUri?: string): Promise<DebugConfiguration | undefined>;
    protected resolveLaunchConfig(config: DebugConfiguration, workspaceFolderUri?: string): Promise<MainClassOption | undefined>;
    protected fixMainClass(config: DebugConfiguration, validationResponse: LaunchValidationResponse, workspaceFolderUri?: string): Promise<MainClassOption | undefined>;
    protected selectMainClass(options: MainClassOption[]): Promise<MainClassOption | undefined>;
    protected formatMainClassOptions(options: MainClassOption[]): QuickPickItem<MainClassOption>[];
    protected startDebugSession(): Promise<any>;
    /**
     * Converts an array of arguments to a string as the args and vmArgs.
     */
    protected concatArgs(args: any[]): string;
}
export {};
//# sourceMappingURL=python-debug-adapter-contribution.d.ts.map